==> merchant-base-0.3.6-RELEASE-sources.jar: com/rocogz/merchant/dto/scm/UpOrderQueryResultDto.java <==
package com.rocogz.merchant.dto.scm;

import lombok.Data;

import java.time.LocalDateTime;

/**
 * <dl>
 * <dd>Description: </dd>
 * <dd>Company: 大诚若谷信息技术有限公司</dd>
 * <dd>@date：2021/3/12 17:01</dd>
 * <dd>@author：ranxiangfu</dd>
 * </dl>
 */
@Data
public class UpOrderQueryResultDto {
    /**
     * 上游订单编号
     */
    private String orderItemCode;
    /**
     * 下游订单编号
     */
    private String orderCode;
    /**
     * 合作客户产品编号
     */
    private String customerProductCode;
    /**
     * 合作客户产品名称
     */
    private String customerProductName;
    /**
     * 代理商产品编号
     */
    private String agentProductCode;
    /**
     * 代理商产品名称
     */
    private String agentProductName ;
    /**
     * 平台产品编号
     */
    private String productCode;
    /**
     * 平台产品名称
     */
    private String productName;
    /**
     * 产品类别
     */
    private String productCategoryCode;
    /**
     * 产品类型
     */
    private String productTypeCode;
    /**
     * 产品类型
     */
    private String productTypeName;
    /**
     * 产品性质
     */
    private String goodsNature;
    /**
     * 第三方产品编码
     */
    private String thirdProductCode;
    /**
     * 发放会员手机号
     */
    private String grantMobile;
    /**
     * 发放会员证件类型
     */
    private String grantIdtype;
    /**
     * 发放会员证件信息
     */
    private String grantIdno;
    /**
     * 发放会员车牌号
     */
    private String grantLicence;
    /**
     * 发放会员姓名
     */
    private String grantUsername;
    /**
     * 发放会员保单号
     */
    private String policyNumber;
    /**
     * 真实会员手机号
     */
    private String realMobile;
    /**
     * 第三方业务状态
     */
    private String thirdBusinessStatus;
    /**
     * 第三方业务号
     */
    private String thirdBusinessCode;
    /**
     * ROCO车服用户券号
     */
    private String rocoUserCouponCode;
    /**
     * 发放张数
     */
    private String grantNum;
    /**
     * 订单价格
     */
    private String detailPrice;
    /**
     * 下单时间
     */
    private LocalDateTime orderTime;
    /**
     * 发放时间
     */
    private LocalDateTime grantTime;
    /**
     * 订单核销状态
     */
    private String writeOffStatus;
    /**
     * 下游订单状态
     */
    private String orderStatus;
    /**
     * 上游订单状态
     */
    private String orderItemStatus;

    private String productCategoryName;
    private String goodsNatureName;
    private String grantIdtypeName;
    private String writeOffStatusName;
    private String orderStatusName;
    private String orderItemStatusName;

    /** 下面的字段明细里会用到 */
    /**
     * 第三方业务编号更新到权益中心状态
     */
    private String powerNoToEquityStatus;

    /**
     * 第三方业务编号更新到权益中心执行次数
     */
    private Integer powerNoToEquityNum;

    private String powerNoToEquityStatusName;
    private String userCouponGrantStatus;
    private String userCouponGrantStatusName;
    private String userCouponGrantRetryNum;
    private String retryNum;
    private LocalDateTime lastestRetryTime;
    private String callbackUrl;
    private Double customerPurchasePrice;
    private Double customerMarketPrice;
    private Double agentPurchasePrice;
    private Double agentMarketPrice;
    private Double purchasePrice;
    private Double marketPrice;
    private String couponCode;
}

==> merchant-base-0.3.7-RELEASE-sources.jar: com/rocogz/merchant/dto/scm/UpOrderQueryResultDto.java <==
package com.rocogz.merchant.dto.scm;

import lombok.Data;

import java.time.LocalDateTime;

/**
 * <dl>
 * <dd>Description: </dd>
 * <dd>Company: 大诚若谷信息技术有限公司</dd>
 * <dd>@date：2021/3/12 17:01</dd>
 * <dd>@author：ranxiangfu</dd>
 * </dl>
 */
@Data
public class UpOrderQueryResultDto {
    /**
     * 上游订单编号
     */
    private String orderItemCode;
    /**
     * 下游订单编号
     */
    private String orderCode;
    /**
     * 合作客户产品编号
     */
    private String customerProductCode;
    /**
     * 合作客户产品名称
     */
    private String customerProductName;
    /**
     * 代理商产品编号
     */
    private String agentProductCode;
    /**
     * 代理商产品名称
     */
    private String agentProductName ;
    /**
     * 平台产品编号
     */
    private String productCode;
    /**
     * 平台产品名称
     */
    private String productName;
    /**
     * 产品类别
     */
    private String productCategoryCode;
    /**
     * 产品类型
     */
    private String productTypeCode;
    /**
     * 产品类型
     */
    private String productTypeName;
    /**
     * 产品性质
     */
    private String goodsNature;
    /**
     * 第三方产品编码
     */
    private String thirdProductCode;
    /**
     * 发放会员手机号
     */
    private String grantMobile;
    /**
     * 发放会员证件类型
     */
    private String grantIdtype;
    /**
     * 发放会员证件信息
     */
    private String grantIdno;
    /**
     * 发放会员车牌号
     */
    private String grantLicence;
    /**
     * 发放会员姓名
     */
    private String grantUsername;
    /**
     * 发放会员保单号
     */
    private String policyNumber;
    /**
     * 真实会员手机号
     */
    private String realMobile;
    /**
     * 第三方业务状态
     */
    private String thirdBusinessStatus;
    /**
     * 第三方业务号
     */
    private String thirdBusinessCode;
    /**
     * ROCO车服用户券号
     */
    private String rocoUserCouponCode;
    /**
     * 发放张数
     */
    private String grantNum;
    /**
     * 订单价格
     */
    private String detailPrice;
    /**
     * 下单时间
     */
    private LocalDateTime orderTime;
    /**
     * 发放时间
     */
    private LocalDateTime grantTime;
    /**
     * 订单核销状态
     */
    private String writeOffStatus;
    /**
     * 下游订单状态
     */
    private String orderStatus;
    /**
     * 上游订单状态
     */
    private String orderItemStatus;

    private String productCategoryName;
    private String goodsNatureName;
    private String grantIdtypeName;
    private String writeOffStatusName;
    private String orderStatusName;
    private String orderItemStatusName;

    /**
     * 发券性质
     */
    private String grantNature;
    /**
     * 发券性质名字
     */
    private String grantNatureName;
    /**
     * 领取验证时间
     */
    private LocalDateTime receiveValidateTime;
    /**
     * 领取验证状态
     */
    private String receiveValidateStatus;
    /**
     * 领取状态名字
     */
    private String receiveValidateStatusName;

    /** 下面的字段明细里会用到 */
    /**
     * 第三方业务编号更新到权益中心状态
     */
    private String powerNoToEquityStatus;

    /**
     * 第三方业务编号更新到权益中心执行次数
     */
    private Integer powerNoToEquityNum;

    private String powerNoToEquityStatusName;
    private String userCouponGrantStatus;
    private String userCouponGrantStatusName;
    private String userCouponGrantRetryNum;
    private String retryNum;
    private LocalDateTime lastestRetryTime;
    private String callbackUrl;
    private Double customerPurchasePrice;
    private Double customerMarketPrice;
    private Double agentPurchasePrice;
    private Double agentMarketPrice;
    private Double purchasePrice;
    private Double marketPrice;
    private String couponCode;
}
